==> opensearch-dashboards-2.6.0.tgz: opensearch-dashboards/src/plugins/opensearch_dashboards_usage_collection/common/constants.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PLUGIN_NAME = exports.PLUGIN_ID = exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = void 0;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const PLUGIN_ID = 'opensearchDashboardsUsageCollection';
exports.PLUGIN_ID = PLUGIN_ID;
const PLUGIN_NAME = 'opensearch_dashboards_usage_collection';
/**
 * The type name used to publish OpenSearch Dashboards usage stats in the formatted as bulk.
 */

exports.PLUGIN_NAME = PLUGIN_NAME;
const OPENSEARCH_DASHBOARDS_STATS_TYPE = 'opensearch_dashboards_stats';
exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = OPENSEARCH_DASHBOARDS_STATS_TYPE;

==> opensearch-dashboards-2.19.1.tgz: opensearch-dashboards/src/plugins/opensearch_dashboards_usage_collection/common/constants.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PLUGIN_NAME = exports.PLUGIN_ID = exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = void 0;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const PLUGIN_ID = exports.PLUGIN_ID = 'opensearchDashboardsUsageCollection';
const PLUGIN_NAME = exports.PLUGIN_NAME = 'opensearch_dashboards_usage_collection';

/**
 * The type name used to publish OpenSearch Dashboards usage stats in the formatted as bulk.
 */
const OPENSEARCH_DASHBOARDS_STATS_TYPE = exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = 'opensearch_dashboards_stats';
